LOSResult
=========

.. currentmodule:: nexoclom

.. autoclass:: LOSResult
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LOSResult.create_model
      ~LOSResult.restore
      ~LOSResult.save

   .. rubric:: Methods Documentation

   .. automethod:: create_model
   .. automethod:: restore
   .. automethod:: save
